/*
Arduino UART communication with VESC. This software reads VESC telemetr data
and displays it on an OLED display. This code is under development for an
improved ppm remote control.

It is written by Sascha Ederer (roboshack.wordpress.com), based on the code
of jenkie (pedelecforum.de), Andreas Chaitidis (Andreas.Chaitidis@gmail.com)
and Benjamin Vedder (www.vedder.se).
Copyright (C) 2016

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
*/
#include "config.h"
//#include "printf.h"
#include "datatypes.h"
#include "vesc_uart.h"
#include <SPI.h>

//Library for the OLED Display
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

mc_values VescMeasuredValues;

float current = 0.0;           //measured battery current
float motor_current = 0.0;     //measured motor current
float voltage = 0.0;           //measured battery voltage
float c_speed = 0.0;           //measured rpm * Pi * wheel diameter [km] * 60 [minutes]
float c_dist = 0.00;           //measured odometry tachometer [turns] * Pi * wheel diameter [km] 
double power = 0.0;              //calculated power

#define OLED_RESET 4
Adafruit_SSD1306 display(OLED_RESET);


//Setup---------------------------------------------------------------------------------------------------------------------
void setup()
{
    
      //  SERIALIO.begin(115200);
        { Serial.begin(115200); }

}

void loop()
{
  if (vesc_get_values(VescMeasuredValues)) { 
      voltage = VescMeasuredValues.v_in;
      current = VescMeasuredValues.current_in;
      motor_current = VescMeasuredValues.current_motor;
     power = current*voltage;
      c_speed = (VescMeasuredValues.rpm/38)*3.14159265359*0.000083*60;
      c_dist = (VescMeasuredValues.tachometer/38)*3.14159265359*0.000083;
      
      Serial.print("Voltage: ");
      Serial.println(voltage);
      Serial.print("current: ");
      Serial.println(current);
      Serial.print("c_speed: ");
      Serial.println(c_speed);
      Serial.print("c_dist: ");
      Serial.println(c_dist);
  }
}
